summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTom Laermans <tom.laermans@powersource.cx>2015-04-16 16:28:34 +0200
committerTom Laermans <tom.laermans@powersource.cx>2015-04-16 16:28:34 +0200
commitec75512455d6a713079b8a20de1c87bfe8d17d8e (patch)
tree8ab9747bc9e1b9a0907da9d544483e1b16a7f316
parent73e02a432de76dad5600a1cadc1a816d46ab6278 (diff)
Add support for PowerConnect 62xx
The pager prompt on the PowerConnect 62xx family does not have a leading space; fixed the expect regex. Also added 6224/6248 to the block ignore regex.
-rw-r--r--lib/oxidized/model/powerconnect.rb7
1 files changed, 3 insertions, 4 deletions
diff --git a/lib/oxidized/model/powerconnect.rb b/lib/oxidized/model/powerconnect.rb
index 531ad0b..0b28f37 100644
--- a/lib/oxidized/model/powerconnect.rb
+++ b/lib/oxidized/model/powerconnect.rb
@@ -4,7 +4,7 @@ class PowerConnect < Oxidized::Model
comment '! '
- expect /^\s--More--\s+.*$/ do |data, re|
+ expect /^\s*--More--\s+.*$/ do |data, re|
send ' '
data.sub re, ''
end
@@ -50,8 +50,8 @@ class PowerConnect < Oxidized::Model
skip_block = false
cfg.each_line do |line|
if line.match /Up\sTime|Temperature|Power Supplies/i
- # For 34xx, 54xx, 55xx, and 8024F we should skip this block (terminated by a blank line)
- skip_block = true if @model =~ /^(34|35)(24|48)$|^(54|55)(24|48)$|^8024$/
+ # For 34xx, 35xx, 54xx, 55xx, 62xx and 8024F we should skip this block (terminated by a blank line)
+ skip_block = true if @model =~ /^(34|35)(24|48)$|^(54|55)(24|48)$|^(62)(24|48)$|^8024$/
end
# If we have lines to skip do this until we reach and empty line
if skip_block
@@ -64,5 +64,4 @@ class PowerConnect < Oxidized::Model
out << "\n"
end
-
end